YAML — Translate Toolkit 3.3.4 documentation

# YAML

New in version 2.0.0.

YAML is a common format for web data interchange. The two variants of YAML files are supported:

- Plain YAML files.

- Ruby YAML localization files with root node as language. This variant supports plurals as well.

# Non-Conformance

The following are not yet supported (in most cases these are properly parsed, but not saved in round trip):

- Booleans:

      foo: True